@@ -6,7 +6,7 @@
 :LastEditors: Kangwenbin
 :Description: 
 """
-from models.db_models.exchange.exchange_model import *
+from seven_shell_studio.models.db_models.exchange.exchange_model import *
 
 class ExchangeModelEx(ExchangeModel):
     def __init__(self, db_connect_key='db_seven_shell', sub_table=None, db_transaction=None, context=None):
